=================================
Windows 8 (or newer) installation
=================================

Machines running recent versions of Windows can run OpenMSIStream programs interactively, or persistently as Windows Services.

.. include:: create_conda_39.rst

.. include:: dll_files.rst

.. include:: libsodium.rst

.. include:: pip_install_openmsistream.rst

